@@ -1,14 +1,17 @@
 {-# LANGUAGE OverloadedStrings #-}
+-- | Prender CSS with renderNestedBlocks
 module Text.CSS.Render
-    ( renderAttr
-    , renderAttrs
-    , renderBlock
+    ( renderNestedBlocks
     , renderBlocks
+    , renderBlock
+    , renderAttrs
+    , renderAttr
     ) where
 
 import Data.Text (Text)
 import Data.Text.Lazy.Builder (Builder, fromText, singleton)
 import Data.Monoid (mappend, mempty, mconcat)
+import Text.CSS.Parse
 
 (<>) :: Builder -> Builder -> Builder
 (<>) = mappend
@@ -27,3 +30,13 @@ renderBlock (sel, attrs) =
 
 renderBlocks :: [(Text, [(Text, Text)])] -> Builder
 renderBlocks = mconcat . map renderBlock
+
+renderNestedBlock :: NestedBlock -> Builder
+renderNestedBlock (LeafBlock b) = renderBlock b
+renderNestedBlock (NestedBlock t bs) = fromText t
+                                    <> singleton '{'
+                                    <> renderNestedBlocks bs 
+                                    <> singleton '}'
+
+renderNestedBlocks :: [NestedBlock] -> Builder
+renderNestedBlocks = mconcat . map renderNestedBlock
